@@ -628,6 +628,16 @@ def get_string_literal_value(string_literal, *, allow_unicode=False):
     assert isinstance(child, Token)
     value = child.value
 
+    assert child.type in ('ESCAPED_STRING', 'ESCAPED_WIDE_STRING')
+    if 'ESCAPED_WIDE_STRING' == child.type:
+        assert len(value) >= 3
+        # Get rid of leading L" and trailing "
+        value = value[2:-1]
+    else:
+        assert len(value) >= 2
+        # Get rid of leading " and trailing "
+        value = value[1:-1]
+
     regex = _get_escape_sequences_regex(allow_unicode=allow_unicode)
     value = regex.sub(_decode_escape_sequence, value)
     # unescape double quote and backslash if preceeded by a backslash
